@@ -50,6 +50,9 @@ class Component:
         self.sdk_chip = [] # # [{'sdk_chip_ch2201':'v7.3'},{'sdk_chip_arm_dummy':'v7.4'}]
         self.mkflash_script = ''
 
+        self.pre_scripts = []
+        self.post_scripts = []
+
     def check_file_integrity(self):
         readme_file = os.path.join(self.path, 'README.md')
         package_file = os.path.join(self.path, 'package.yaml')
@@ -266,7 +269,16 @@ class Component:
         self.loaded = True
         return True
 
-    def variable_convert(self, varList):
+    def variable_convert(self, varList, file_non_existent_no_err=False):
+        # script
+        def script_filename_convert(root_path, script_file):
+            script_filename = varList.convert(script_file)
+            if script_filename != None:
+                script_file = os.path.join(root_path, script_filename)
+            return script_file
+        self.build_config.prebuild_script = script_filename_convert(self.path, self.build_config.prebuild_script)
+        self.build_config.postbuild_script = script_filename_convert(self.path, self.build_config.postbuild_script)
+ 
         # include
         incs = []
         for inc in self.build_config.include:
@@ -336,9 +348,11 @@ class Component:
                 filename = os.path.join(self.path, fn)
                 if not os.path.isfile(filename):
                     if not ('*' in filename or '?' in filename):
-                        logger.error('component `%s`: %s is not exists.' %
-                                     (self.name, filename))
-                        exit(-1)
+                        if not file_non_existent_no_err:
+                            logger.error('component `%s`: %s is not exists.' % (self.name, filename))
+                            exit(-1)
+                        else:
+                            logger.warning('component `%s`: %s is not exists.' % (self.name, filename))
                 sources.append(fn)
         self.source_files = sources
 
