@@ -11,7 +11,7 @@ from .log import logger
 from .tools import *
 from .package import *
 from .component import *
-
+from .builder import *
 
 class Variables:
     def __init__(self):
@@ -55,7 +55,7 @@ class Variables:
 
 
 class Solution:
-    def __init__(self, components):
+    def __init__(self, components, file_non_existent_no_err=False):
         self.variables = Variables()
         self.solution_component = None       # 当前 solution 组件
         self.board_component = None          # 当前开发板组件
@@ -78,6 +78,7 @@ class Solution:
         self.ld_script_component = None
         self.cpu_name = ''
         self.toolchain_prefix = ''
+        self.toolchain_path = ''
         self.algorithms_path = ''
         self.mkflash_script = ''
 
@@ -211,6 +212,14 @@ class Solution:
                 for c in component.build_config.ldflag.split():
                     self.LINKFLAGS.append(c)
 
+        # pre/post script
+        for component in [self.chip_component, self.board_component, self.solution_component]:
+            if component:
+                if component.build_config.prebuild_script:
+                    self.solution_component.pre_scripts.append(os.path.join(component.path, component.build_config.prebuild_script))
+                if component.build_config.postbuild_script:
+                    self.solution_component.post_scripts.append(os.path.join(component.path, component.build_config.postbuild_script))
+
         # 根据 cpu_id 加载配置
         if len(solution_hw_info.cpu_list) != 0 and not solution_hw_info.cpu_id:
             put_string("Please set hw_info.cpu_id.", level='error')
@@ -277,7 +286,7 @@ class Solution:
                     self.depend_libs.append(os.path.join(
                         self.lib_path, 'lib' + component.name + '.a'))
 
-            component.variable_convert(self.variables)
+            component.variable_convert(self.variables, file_non_existent_no_err)
 
             # include
             for path in component.build_config.include:
@@ -307,6 +316,7 @@ class Solution:
                     break
 
         self.toolchain_prefix = solution_hw_info.toolchain_prefix
+        self.toolchain_path = solution_hw_info.toolchain_path
         self.ld_script = solution_hw_info.ld_script
         self.ld_script = self.variables.convert(self.ld_script)
         self.algorithms_path = solution_hw_info.flash_program
@@ -384,12 +394,26 @@ class Solution:
                 put_string('    %s = %s' % (k, v))
 
         if show_flags:
-            put_string("ASFLAGS   :" + ' '.join(self.ASFLAGS))
+            build_env = Builder(self)
+            for a in build_env.env['ASFLAGS']:
+                if a not in self.ASFLAGS:
+                    self.ASFLAGS.insert(0, a)
+            for a in build_env.env['CCFLAGS']:
+                if a not in self.CCFLAGS:
+                    self.CCFLAGS.insert(0, a)
+            for a in build_env.env['CXXFLAGS']:
+                if a not in self.CXXFLAGS:
+                    self.CXXFLAGS.insert(0, a)
+            for a in build_env.env['LINKFLAGS']:
+                if a not in self.LINKFLAGS:
+                    self.LINKFLAGS.insert(0, a)
+            put_string("ASMFLAGS  :" + ' '.join(self.ASFLAGS))
             put_string("CCFLAGS   :" + ' '.join(self.CCFLAGS))
             put_string("CXXFLAGS  :" + ' '.join(self.CXXFLAGS))
             put_string("LINKFLAGS :" + ' '.join(self.LINKFLAGS))
             put_string('ld_script : ' + self.ld_script)
             put_string('toolchain : ' + self.toolchain_prefix)
+            put_string('toolchain_path : ' + self.toolchain_path)
             put_string('algorithms_path : ' + self.algorithms_path)
 
 
@@ -423,7 +447,7 @@ def riscv_cpu_id(cpu):
         return 'rv32f_32gpr'
     elif a == 'e906f':
         return 'rv32f_32gpr'
-    elif a == 'e906fd':
+    elif a == 'e906fd' or a == 'e907fd' or a == 'e907fdp':
         return 'rv32fd_32gpr'
     elif a == 'c906':
         return 'rv64_32gpr'
