@@ -20,6 +20,9 @@ Install toolchain.
 """
 
     def _Options(self, p):
+        p.add_option('-f', '--force',
+                     dest='force', action='store_true',
+                     help=' install toolchain force')
         p.add_option('-c', '--csky',
                      dest='install_csky', action='store_true',
                      help=' install csky-elfabiv2-tools')
@@ -39,15 +42,15 @@ Install toolchain.
         need_usage = True
         tool = ToolchainYoC()
         if opt.install_all:
-            tool.check_toolchain('csky-abiv2-elf', 1)
-            tool.check_toolchain('riscv64-unknown-elf', 1)
+            tool.check_toolchain('csky-abiv2-elf', 1, force=opt.force)
+            tool.check_toolchain('riscv64-unknown-elf', 1, force=opt.force)
             need_usage = False
         else:
             if opt.install_csky:
-                tool.check_toolchain('csky-abiv2-elf', 1)
+                tool.check_toolchain('csky-abiv2-elf', 1, force=opt.force)
                 need_usage = False
             if opt.install_riscv:
-                tool.check_toolchain('riscv64-unknown-elf', 1)
+                tool.check_toolchain('riscv64-unknown-elf', 1, force=opt.force)
                 need_usage = False
         if need_usage:
             self.Usage()
