@@ -11,6 +11,7 @@ import tarfile
 import subprocess
 import platform
 import codecs
+import shutil
 
 from .tools import *
 
@@ -134,9 +135,13 @@ class ToolchainYoC:
         with codecs.open(rc, 'w', 'UTF-8') as f:
             contents = f.writelines(contents)
 
-    def check_toolchain(self, arch='csky-abiv2-elf', verbose=0):
+    def check_toolchain(self, arch='csky-abiv2-elf', verbose=0, force=False):
         bin_file = self.check_program(arch)
-        if bin_file == '':
+        if bin_file == '' or force:
+            if force:
+                toolchain_path = os.path.join(self.basepath, arch)
+                if os.path.exists(toolchain_path):
+                    shutil.rmtree(toolchain_path)
             self.download(arch)
             bin_file = self.check_program(arch)
         else:
